/*!
 * Copyright (c) 2021 by Contributors
 */
#ifndef TREELITE_VERSION_CONFIG_H_
#define TREELITE_VERSION_CONFIG_H_

#define TREELITE_VER_MAJOR 2
#define TREELITE_VER_MINOR 2
#define TREELITE_VER_PATCH 1

#endif  // TREELITE_VERSION_CONFIG_H_
